package com.css.simulation.resource.server.domain.service;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.constants.DictConstants;
import api.common.pojo.param.MinioParameter;
import api.common.pojo.param.project.SimulationManualProjectParam;
import api.common.pojo.po.project.SimulationManualProjectPO;
import api.common.pojo.vo.project.ProjectReportVO;
import com.css.simulation.resource.server.acl.feign.FileDownService;
import com.css.simulation.resource.server.application.service.SimulationProjectService;
import com.css.simulation.resource.server.infrastructure.mysql.mapper.SimulationProjectMapper;
import com.css.simulation.resource.server.infrastructure.mysql.mapper.SimulationProjectTaskMapper;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

@org.springframework.stereotype.Service
public class ProjectDomainService {

    @Resource
    private SimulationProjectService simulationProjectService;
    @Resource
    private SimulationProjectMapper simulationProjectMapper;
    @Resource
    private SimulationProjectTaskMapper simulationProjectTaskMapper;
    @Resource
    private FileDownService fileDownService;

    public String getLastProjectIdByAlgorithmId(String algorithmId) {
        return simulationProjectService.selectLastProjectIdByAlgorithmId(algorithmId);
    }

    public String getProjectTypeByProjectId(String projectId) {
        SimulationManualProjectPO simulationManualProjectPO = simulationProjectMapper.selectProjectById(SimulationManualProjectParam.builder().id(projectId).build());
        if (simulationManualProjectPO != null) {
            return DictConstants.PROJECT_TYPE_MANUAL;
        } else {
            return DictConstants.PROJECT_TYPE_AUTO_SUB;
        }
    }

    public ProjectReportVO getProjectReport(SimulationManualProjectParam simulationManualProjectParam) {
        ResponseBodyVO<ProjectReportVO> vo = simulationProjectService.selectProjectReportById(simulationManualProjectParam);
        return vo.getInfo();
    }

    public List<String> getVideoList(SimulationManualProjectParam simulationManualProjectParam) {
        List<String> videoList = new ArrayList<>();
        List<String> runResultPaths = simulationProjectTaskMapper.selectRunResultPathByProjectId(simulationManualProjectParam);
        for (String runResultPath : runResultPaths) {
            ResponseBodyVO<List<String>> list = fileDownService.list(MinioParameter.builder().objectName(runResultPath).build());
            List<String> info = list.getInfo();
            for (String s : info) {
                if (s.contains(".mp4")) {
                    videoList.add(s);
                }
            }
        }
        return videoList;
    }
}
